==> rosegarden-trinity-3.5.13.2.tar.xz: rosegarden-trinity-3.5.13.2/src/gui/studio/MidiDeviceListViewItem.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_MIDIDEVICELISTVIEWITEM_H_
#define _RG_MIDIDEVICELISTVIEWITEM_H_

#include "base/Device.h"
#include <klistview.h>
#include <tqstring.h>


namespace Rosegarden
{



class MidiDeviceListViewItem : public KListViewItem
{
public:
    // Device
    MidiDeviceListViewItem(DeviceId id,
                           TQListView* parent, TQString name);

    // Bank
    MidiDeviceListViewItem(DeviceId id,
                           TQListViewItem* parent, TQString name,
                           bool percussion,
                           int msb, int lsb);

    // Key Mapping
    MidiDeviceListViewItem(DeviceId id,
                           TQListViewItem* parent, TQString name);

    DeviceId getDeviceId() const { return m_deviceId; }

    virtual int compare(TQListViewItem *i, int col, bool ascending) const;

protected:

    //--------------- Data members ---------------------------------
    DeviceId m_deviceId;
};


}

#endif

==> rosegarden-trinity-14.0.8.tar.xz: rosegarden-trinity-14.0.8/src/gui/studio/MidiDeviceListViewItem.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.

    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>

    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_MIDIDEVICELISTVIEWITEM_H_
#define _RG_MIDIDEVICELISTVIEWITEM_H_

#include "base/Device.h"
#include <tdelistview.h>
#include <tqstring.h>


namespace Rosegarden
{



class MidiDeviceListViewItem : public TDEListViewItem
{
public:
    // Device
    MidiDeviceListViewItem(DeviceId id,
                           TQListView* parent, TQString name);

    // Bank
    MidiDeviceListViewItem(DeviceId id,
                           TQListViewItem* parent, TQString name,
                           bool percussion,
                           int msb, int lsb);

    // Key Mapping
    MidiDeviceListViewItem(DeviceId id,
                           TQListViewItem* parent, TQString name);

    DeviceId getDeviceId() const { return m_deviceId; }

    virtual int compare(TQListViewItem *i, int col, bool ascending) const;

protected:

    //--------------- Data members ---------------------------------
    DeviceId m_deviceId;
};


}

#endif
